@@ -109,7 +109,7 @@ class TestDecoratorUnit:
         """)
         _, etrs, _ = adaptavist_mock
         pytester.runpytest("--adaptavist")
-        etrs.call_args.kwargs["test_case_key"] == "MARKER-T16"
+        assert etrs.call_args.kwargs["test_case_key"] == "MARKER-T16"
 
     @pytest.mark.usefixtures("configure")
     def test_respect_project_decorator_if_project_key_set(self, pytester: pytest.Pytester, adaptavist_mock: AdaptavistMock):
